==> openshift-model-operatorhub-6.9.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SubscriptionCatalogHealthFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class SubscriptionCatalogHealthFluent<A extends SubscriptionCatalogHealthFluent<A>> extends BaseFluent<A>{
  public SubscriptionCatalogHealthFluent() {
  }
  
  public SubscriptionCatalogHealthFluent(SubscriptionCatalogHealth instance) {
    this.copyInstance(instance);
  }
  private ObjectReferenceBuilder catalogSourceRef;
  private Boolean healthy;
  private String lastUpdated;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(SubscriptionCatalogHealth instance) {
    instance = (instance != null ? instance : new SubscriptionCatalogHealth());
    if (instance != null) {
          this.withCatalogSourceRef(instance.getCatalogSourceRef());
          this.withHealthy(instance.getHealthy());
          this.withLastUpdated(instance.getLastUpdated());
          this.withCatalogSourceRef(instance.getCatalogSourceRef());
          this.withHealthy(instance.getHealthy());
          this.withLastUpdated(instance.getLastUpdated());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public ObjectReference buildCatalogSourceRef() {
    return this.catalogSourceRef != null ? this.catalogSourceRef.build() : null;
  }
  
  public A withCatalogSourceRef(ObjectReference catalogSourceRef) {
    this._visitables.remove(this.catalogSourceRef);
    if (catalogSourceRef != null) {
        this.catalogSourceRef = new ObjectReferenceBuilder(catalogSourceRef);
        this._visitables.get("catalogSourceRef").add(this.catalogSourceRef);
    } else {
        this.catalogSourceRef = null;
        this._visitables.get("catalogSourceRef").remove(this.catalogSourceRef);
    }
    return (A) this;
  }
  
  public boolean hasCatalogSourceRef() {
    return this.catalogSourceRef != null;
  }
  
  public CatalogSourceRefNested<A> withNewCatalogSourceRef() {
    return new CatalogSourceRefNested(null);
  }
  
  public CatalogSourceRefNested<A> withNewCatalogSourceRefLike(ObjectReference item) {
    return new CatalogSourceRefNested(item);
  }
  
  public CatalogSourceRefNested<A> editCatalogSourceRef() {
    return withNewCatalogSourceRefLike(java.util.Optional.ofNullable(buildCatalogSourceRef()).orElse(null));
  }
  
  public CatalogSourceRefNested<A> editOrNewCatalogSourceRef() {
    return withNewCatalogSourceRefLike(java.util.Optional.ofNullable(buildCatalogSourceRef()).orElse(new ObjectReferenceBuilder().build()));
  }
  
  public CatalogSourceRefNested<A> editOrNewCatalogSourceRefLike(ObjectReference item) {
    return withNewCatalogSourceRefLike(java.util.Optional.ofNullable(buildCatalogSourceRef()).orElse(item));
  }
  
  public Boolean getHealthy() {
    return this.healthy;
  }
  
  public A withHealthy(Boolean healthy) {
    this.healthy = healthy;
    return (A) this;
  }
  
  public boolean hasHealthy() {
    return this.healthy != null;
  }
  
  public String getLastUpdated() {
    return this.lastUpdated;
  }
  
  public A withLastUpdated(String lastUpdated) {
    this.lastUpdated = lastUpdated;
    return (A) this;
  }
  
  public boolean hasLastUpdated() {
    return this.lastUpdated != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubscriptionCatalogHealthFluent that = (SubscriptionCatalogHealthFluent) o;
    if (!java.util.Objects.equals(catalogSourceRef, that.catalogSourceRef)) return false;
    if (!java.util.Objects.equals(healthy, that.healthy)) return false;
    if (!java.util.Objects.equals(lastUpdated, that.lastUpdated)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(catalogSourceRef,  healthy,  lastUpdated,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (catalogSourceRef != null) { sb.append("catalogSourceRef:"); sb.append(catalogSourceRef + ","); }
    if (healthy != null) { sb.append("healthy:"); sb.append(healthy + ","); }
    if (lastUpdated != null) { sb.append("lastUpdated:"); sb.append(lastUpdated + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withHealthy() {
    return withHealthy(true);
  }
  public class CatalogSourceRefNested<N> extends ObjectReferenceFluent<CatalogSourceRefNested<N>> implements Nested<N>{
    CatalogSourceRefNested(ObjectReference item) {
      this.builder = new ObjectReferenceBuilder(this, item);
    }
    ObjectReferenceBuilder builder;
    
    public N and() {
      return (N) SubscriptionCatalogHealthFluent.this.withCatalogSourceRef(builder.build());
    }
    
    public N endCatalogSourceRef() {
      return and();
    }
    
  
  }

}

==> openshift-model-operatorhub-6.13.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SubscriptionCatalogHealthFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class SubscriptionCatalogHealthFluent<A extends SubscriptionCatalogHealthFluent<A>> extends BaseFluent<A>{
  public SubscriptionCatalogHealthFluent() {
  }
  
  public SubscriptionCatalogHealthFluent(SubscriptionCatalogHealth instance) {
    this.copyInstance(instance);
  }
  private ObjectReferenceBuilder catalogSourceRef;
  private Boolean healthy;
  private String lastUpdated;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(SubscriptionCatalogHealth instance) {
    instance = (instance != null ? instance : new SubscriptionCatalogHealth());
    if (instance != null) {
          this.withCatalogSourceRef(instance.getCatalogSourceRef());
          this.withHealthy(instance.getHealthy());
          this.withLastUpdated(instance.getLastUpdated());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public ObjectReference buildCatalogSourceRef() {
    return this.catalogSourceRef != null ? this.catalogSourceRef.build() : null;
  }
  
  public A withCatalogSourceRef(ObjectReference catalogSourceRef) {
    this._visitables.remove("catalogSourceRef");
    if (catalogSourceRef != null) {
        this.catalogSourceRef = new ObjectReferenceBuilder(catalogSourceRef);
        this._visitables.get("catalogSourceRef").add(this.catalogSourceRef);
    } else {
        this.catalogSourceRef = null;
        this._visitables.get("catalogSourceRef").remove(this.catalogSourceRef);
    }
    return (A) this;
  }
  
  public boolean hasCatalogSourceRef() {
    return this.catalogSourceRef != null;
  }
  
  public CatalogSourceRefNested<A> withNewCatalogSourceRef() {
    return new CatalogSourceRefNested(null);
  }
  
  public CatalogSourceRefNested<A> withNewCatalogSourceRefLike(ObjectReference item) {
    return new CatalogSourceRefNested(item);
  }
  
  public CatalogSourceRefNested<A> editCatalogSourceRef() {
    return withNewCatalogSourceRefLike(java.util.Optional.ofNullable(buildCatalogSourceRef()).orElse(null));
  }
  
  public CatalogSourceRefNested<A> editOrNewCatalogSourceRef() {
    return withNewCatalogSourceRefLike(java.util.Optional.ofNullable(buildCatalogSourceRef()).orElse(new ObjectReferenceBuilder().build()));
  }
  
  public CatalogSourceRefNested<A> editOrNewCatalogSourceRefLike(ObjectReference item) {
    return withNewCatalogSourceRefLike(java.util.Optional.ofNullable(buildCatalogSourceRef()).orElse(item));
  }
  
  public Boolean getHealthy() {
    return this.healthy;
  }
  
  public A withHealthy(Boolean healthy) {
    this.healthy = healthy;
    return (A) this;
  }
  
  public boolean hasHealthy() {
    return this.healthy != null;
  }
  
  public String getLastUpdated() {
    return this.lastUpdated;
  }
  
  public A withLastUpdated(String lastUpdated) {
    this.lastUpdated = lastUpdated;
    return (A) this;
  }
  
  public boolean hasLastUpdated() {
    return this.lastUpdated != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubscriptionCatalogHealthFluent that = (SubscriptionCatalogHealthFluent) o;
    if (!java.util.Objects.equals(catalogSourceRef, that.catalogSourceRef)) return false;
    if (!java.util.Objects.equals(healthy, that.healthy)) return false;
    if (!java.util.Objects.equals(lastUpdated, that.lastUpdated)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(catalogSourceRef,  healthy,  lastUpdated,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (catalogSourceRef != null) { sb.append("catalogSourceRef:"); sb.append(catalogSourceRef + ","); }
    if (healthy != null) { sb.append("healthy:"); sb.append(healthy + ","); }
    if (lastUpdated != null) { sb.append("lastUpdated:"); sb.append(lastUpdated + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withHealthy() {
    return withHealthy(true);
  }
  public class CatalogSourceRefNested<N> extends ObjectReferenceFluent<CatalogSourceRefNested<N>> implements Nested<N>{
    CatalogSourceRefNested(ObjectReference item) {
      this.builder = new ObjectReferenceBuilder(this, item);
    }
    ObjectReferenceBuilder builder;
    
    public N and() {
      return (N) SubscriptionCatalogHealthFluent.this.withCatalogSourceRef(builder.build());
    }
    
    public N endCatalogSourceRef() {
      return and();
    }
    
  
  }

}
